@@ -63,7 +63,7 @@ LearnerClassifDebug = R6Class("LearnerClassifDebug", inherit = LearnerClassif,
           segfault_predict     = p_dbl(0, 1, default = 0, tags = "predict"),
           segfault_train       = p_dbl(0, 1, default = 0, tags = "train"),
           sleep_train          = p_uty(tags = "train"),
-          sleep_predict        = p_uty(tags = "train"),
+          sleep_predict        = p_uty(tags = "predict"),
           threads              = p_int(1L, tags = c("train", "threads")),
           warning_predict      = p_dbl(0, 1, default = 0, tags = "predict"),
           warning_train        = p_dbl(0, 1, default = 0, tags = "train"),
