@@ -124,7 +124,7 @@ MeasureSimilaritySimple = R6Class("MeasureSimilaritySimple",
         minimize = info$minimize,
         average = "custom",
         aggregator = agg,
-        predict_type = "response",
+        predict_type = NA_character_,
         packages = "mlr3measures",
         label = info$title,
         man = paste0("mlr3::mlr_measures_sim.", name),
