@@ -42,7 +42,8 @@ NULL
 
 load_task_german_credit = function(id = "german_credit") {
   b = as_data_backend(readRDS(system.file("extdata", "german_credit.rds", package = "mlr3")))
-  task = TaskClassif$new(id, b, target = "credit_risk", positive = "good")
+  task = TaskClassif$new(id, b, target = "credit_risk", positive = "good",
+    label = "German Credit")
   b$hash = task$man = "mlr3::mlr_tasks_german_credit"
   task
 }
