@@ -20,3 +20,9 @@ test_that("mlr_learners: sugar", {
   expect_equal(lrn$param_set$values$cp, 0.001)
   expect_equal(lrn$predict_type, "prob")
 })
+
+test_that("as.data.table(..., objects = TRUE)", {
+  tab = as.data.table(mlr_learners, objects = TRUE)
+  expect_data_table(tab)
+  expect_list(tab$object, "Learner", any.missing = FALSE)
+})
